.TH PCAL 1
.SH NAME
pcal \- generate PostScript calendars
.SH SYNOPSIS
.B pcal
[
.BR \-e
|
.BR \-f
<cal>
]
[
.BR \-o
<file>
]
[
.BR \-l
|
.BR \-p
]
[
.BR \-b
<day>
|
all
]*
[
.BR \-g
<day>
|
all
]*
[
.B -t
<titlefont name>
]
[
.B -d
<dayfont name>
]
[
.B -n
<notesfont name>
]
[
.B -N
<language number>
]
[
.B -L
<foot string>
]
[
.B -C
<foot string>
]
[
.B -R
<foot string>
]
[
.B -D
<symbol>
]
[
.B -U
<symbol>
]
[
.B month
] [
.B year
] [
.B nmonths
]
.SH DESCRIPTION
.I Pcal
generates PostScript to produce landscape or portrait calendars for any 
month and year. The arguments
.BR month ,
.BR year ,
and
.BR nmonths ,
if provided, should be numeric. The month should be in the range 1 - 12,
and year should be specified as 1 or 2 digits or as the full 4 digit year.
.P
If no numeric arguments are provided, the current month and year will be
generated.
.P
If one numeric argument is provided, it is interpreted as the year; the
entire year will be generated. Otherwise, 
.I nmonth
months, starting with
.I month
and
.I year,
will be generated.
.PP
If a file named
.I \.calendar
or
.I calendar
(for compatibility with older versions)
exists in the caller's home directory (or in the directory pointed to by
environment variable PCAL_DIR), it will be searched for lines with
leading dates matching the requested month and year (current by default).
Any text following the date will be printed on the calendar under the
appropriate day of the month. Dates in the
.I \.calendar
file may consist of a numeric or alpha month (at least the first 3 characters
for month names) followed by a numeric day and optionally followed by a
year. Any non-numeric character may separate numeric dates. Holidays may
be flagged by following the date immediately with '*'; this will cause the
date to be printed in gray.
.PP
Lines in the
.I \.calendar
file consisting of "year xxxx" (where xxxx is a numeric year) can be used
to set the year for following entries. This assumes that the following
entries do not contain a year; any date entries containing year information
will set the remembered year to that year.
.PP
Lines in the
.I \.calendar
file consisting of "opt <options>" can be used to override the defaults for
any command-line flags except -e, -f, -D, and -U. Any flags specified in this
manner
are, in turn, overridden by those specified explicitly on the command line.
.PP
Comments ('#' through end-of-line) are supported.
.PP
Release 2.1 of pcal adds rudimentary cpp-like functionality to the
date file, supporting 
.BR define |
.BR undef ,
.B if{n}def ... {else ...} endif,
and
.BR include.
Note that these are not preceded by '#' as they are in C.
.PP	
Symbol names are case-insensitive. It is not an error to "undef"
an undefined symbol, nor to "define" a previously-defined one.
.PP
"ifdef" alone is always false; "ifndef" alone is always true.
.PP
The name of the file in the "include" directive may optionally be
surrounded by either "" or <>, both of which are ignored. If the
name is not an absolute path, it is taken to be relative to the
directory where the file containing the directive is located.
.I Pcal
is smart enough to translate "~/" to the user's home directory.
.PP
.I Pcal
has many options:
.P
.TP
.B \-e
Print an empty calendar. Do not print entries from a calendar file.
.TP
.B \-f <cal>
Directs
.I pcal
to use the file name <cal> as the input file in place of the default
.I \.calendar
file in the callers home directory (or directory pointed to
by PCAL_DIR).
.TP
.B \-o <file>
Directs
.I pcal
to write the output to <file> instead of to stdout.
.TP
.B \-l
This will cause the output to come out in landscape mode (default).
.TP
.B \-p
This will cause the output to come out in portrait mode.
.TP
.B \-b <day> | all
This will cause all dates falling on weekday <day> to be printed in black;
"-b all" causes all weekdays to be printed in black.
.TP
.B \-g <day> | all
This will cause all dates falling on weekday <day> to be printed in gray;
"-g all" causes all weekdays to be printed in gray.
.IP
(The default for the -b and -g flags is to print Saturdays and Sundays in
gray and other days - unless flagged as holidays - in black.)
.TP
.B \-t <titlefont name>
This option can be used to change the font the title
is printed in. (ie. pcal -t Times-Roman).
.TP
.B \-d <dayfont name>
This option is the same as -t except that the font used
to print the day numbers is changed.
.TP
.B \-n <notesfont name>
This option is the same as -n except that the font used
to print the notes in the calendar boxes is changed.
.TP
.B \-N <language number>
This option selects the language used for the month and
weekday text labels.  The default is 0 = english, and the
other alternatives are 1 = finnish and 2 = swedish.
.TP
.B \-D <symbol>
This option defines the named symbol prior to reading the date file.
.TP
.B \-U <symbol>
This option un-defines the named symbol prior to reading the date file.
.TP
.B \-L <string>
This option causes the accompanying string to be printed as a left footer.
.TP
.B \-C <string>
This option causes the accompanying string to be printed as a center footer.
.TP
.B \-R <string>
This option causes the accompanying string to be printed as a right footer.
.IP
Any option which normally takes an argument may be specified without
the argument in order to reset the value to the program default.
.B \-D
alone clears all the defined symbols;
.B \-U
alone has no effect.  The
.B \-
(or
.BR \-\- ,
System V people)
flag may be used to disambiguate cases such as "pcal -t 9 90"; this
could be written instead as "pcal -t - 9 90" or "pcal -t -- 9 90".
.IP
If the environment variable PCAL_OPTS is defined, its contents are
parsed as a command line.  Flags set via PCAL_OPTS override the
program defaults, but are overridden by flags set via "opt" lines
in the date file or explicitly on the command line.
.SH SEE ALSO
cal(1)
.SH CAVEATS
The original PostScript code to generate the calendars was written by
Patrick Wood (Copywrite (c) 1987 by Patrick Wood of Pipeline Associates,
Inc.), and authorized for modification and redistribution. The calendar
file inclusion code was originally written in "bs(1)" by Bill Vogel of
AT&T. Patrick's original PostScript was modified and enhanced several
times by others whos names have regrettably been lost. Ken Keirnan of
Pacific Bell assembled the original "C" version upon which this is based;
additional modifications and enhancements were the work of Joseph P.
Larson, Ed Hand, Andrew W. Rogers, Mark Kantrowitz, Joe Brownlee, and
Eric Hammond.
