/*
 * pcalinit.h - provides the PostScript routines for v2.1 of pcal.c
 *
 * 2.1	modified by Mark Kantrowitz:
 *
 *	use symbolic names instead of magic numbers throughout
 *	support -L, -C, -R, -n options (all new)
 *	print holiday text in otherwise-wasted space next to date
 *	use larger text for dates in large calendars
 *
 * 2.0	modified by Andrew W. Rogers:
 *
 *	skip printing days of week on small calendars
 *	center month and year at top of calendar
 *	use correct algorithm for leap year calculation
 *	get month and day names from main program
 *	use table to determine color (black/gray) of weekdays and holidays
 *      use hanging indent to print continued text lines
 *
 */

char *header_1[] = {
  "/titlefontsize 48 def",
  "/weekdayfontsize 12 def",
  "/footfontsize 12 def",
  "/datefontsize 30 def",
  "/savedatefontsize datefontsize def",
  "/notesfontsize 6 def",
  "/daywidth 100 def",
  "/dayheight 80 def",
  "/negdaywidth 0 daywidth sub def",
  "/negdayheight 0 dayheight sub def",
  "/prtnum { 3 string cvs show} def",
  "/drawgrid {\t\t% draw calendar boxes",
  "\tdayfont findfont weekdayfontsize scalefont setfont",
  "\t0 1 6 {",
  "\t\t/i exch def",
  "\t\tsubmonth 0 eq {",
  "\t\t\ti daywidth mul 40 moveto",
  "\t\t\tday_names i get",
  "\t\t\tdaywidth center",
  "\t\t} if",
  "\t\ti daywidth mul 35 moveto",
  "\t\t1.0 setlinewidth",
  "\t\t0 1 5 {",
  "\t\t\tgsave",
  "\t\t\tdaywidth 0 rlineto ",
  "\t\t\t0 negdayheight rlineto",
  "\t\t\tnegdaywidth 0 rlineto",
  "\t\t\tclosepath stroke",
  "\t\t\tgrestore",
  "\t\t\t0 negdayheight rmoveto",
  "\t\t pop } for",
  "\t} for",
  "} def",
  "/drawnums {\t\t% place day numbers on calendar",
  "\tdayfont findfont datefontsize scalefont setfont",
  "\t/start startday def",
  "\t/days ndays def",
  "\t/fontdiff datefontsize savedatefontsize sub def",
  "\t/n 0 def",
  "\tstart daywidth mul 5 add 10 fontdiff sub rmoveto",
  "\t1 1 days {",
  "\t\t/day exch def",
  "\t\tgsave",
  "\t\tsubmonth 0 eq {",
  "\t\t\t/gray day_gray day start add 1 sub 7 mod get def",
  "\t\t\tday holidays n get eq {",
  "\t\t\t\t/gray holiday_gray def",
  "\t\t\t\t/n n 1 add def",
  "\t\t\t} if",
  "\t\t\tgray {",
  "\t\t\t\t0.8 setgray",
  "\t\t\t} if",
  "\t\t} if",
  "\t\tday prtnum",
  "\t\tgrestore",
  "\t\tday start add 7 mod 0 eq",
  "\t\t{",
  "\t\t\tcurrentpoint exch pop dayheight sub 5 exch moveto",
  "\t\t}",
  "\t\t{",
  "\t\t\tdaywidth 0 rmoveto",
  "\t\t} ifelse",
  "\t} for",
  "} def",
  "/drawfill {\t\t% place fill squares on calendar",
  "\t/start startday def",
  "\t/days ndays def",
  "\t0 35 rmoveto",
  "\t1.0 setlinewidth",
  "\t0 1 start 1 sub {",
  "\t\tgsave",
  "\t\t.9 setgray",
  "\t\tdaywidth 0 rlineto ",
  "\t\t0 negdayheight rlineto",
  "\t\tnegdaywidth 0 rlineto",
  "\t\tclosepath fill",
  "\t\tgrestore",
  "\t\tdaywidth 0 rmoveto",
  "\tpop } for",
  "\tsubmonth 1 eq",
  "\t{",
  "\t\t/lastday 42 def",
  "\t\t600 -365 moveto",
  "\t}",
  "\t{",
  "\t\t/lastday 40 def",
  "\t\t400 -365 moveto",
  "\t} ifelse",
  "\tlastday -1 ndays start 1 add add",
  "\t{",
  "\t\t/day exch def",
  "\t\tgsave",
  "\t\t.9 setgray",
  "\t\tdaywidth 0 rlineto ",
  "\t\t0 negdayheight rlineto",
  "\t\tnegdaywidth 0 rlineto",
  "\t\tclosepath fill",
  "\t\tgrestore",
  "\t\tday 7 mod 1 eq",
  "\t\t{",
  "\t\t\t600 -365 dayheight add moveto",
  "\t\t}",
  "\t\t{",
  "\t\t\tnegdaywidth 0 rmoveto",
  "\t\t} ifelse",
  "\t} for",
  "} def",
  "/isleap {\t\t% is this a leap year?",
  "\tyear 4 mod 0 eq\t\t% multiple of 4",
  "\tyear 100 mod 0 ne \t% not century",
  "\tyear 400 mod 0 eq or and\t% or divisible by 400",
  "} def",
  "/days_month [ 31 28 31 30 31 30 31 31 30 31 30 31 ] def",
  "/ndays {\t\t% number of days in this month",
  "\tdays_month month 1 sub get",
  "\tmonth 2 eq\t% Feb",
  "\tisleap and",
  "\t{",
  "\t\t1 add",
  "\t} if",
  "} def",
  "/startday {\t\t% starting day-of-week for this month",
  "\t/off year 2000 sub def\t% offset from start of epoch",
  "\toff",
  "\toff 4 idiv add\t\t% number of leap years",
  "\toff 100 idiv sub\t% number of centuries",
  "\toff 400 idiv add\t% number of years divisible by 400",
  "\t6 add 7 mod 7 add \t% offset from Jan 1 2000",
  "\t/off exch def",
  "\t1 1 month 1 sub {",
  "\t\t/idx exch def",
  "\t\tdays_month idx 1 sub get",
  "\t\tidx 2 eq",
  "\t\tisleap and",
  "\t\t{",
  "\t\t\t1 add",
  "\t\t} if",
  "\t\t/off exch off add def",
  "\t} for",
  "\toff 7 mod\t\t% 0--Sunday, 1--monday, etc.",
  "} def",
  "/center {\t\t% center string in given width",
  "\t/width exch def",
  "\t/str exch def width str ",
  "\tstringwidth pop sub 2 div 0 rmoveto str show",
  "} def",
  "/strcat {\t\t% concatenate two strings",
  "\t2 copy",
  "\tlength exch length",
  "\tdup 3 -1 roll add",
  "\tstring",
  "\tdup 0 6 -1 roll putinterval",
  "\tdup 3 -1 roll 4 -1 roll putinterval",
  "} def",
  "/calendar",
  "{",
  "\ttitlefont findfont titlefontsize scalefont setfont",
  "\t/month_name month_names month 1 sub get def",
  "\t/yearstring year 10 string cvs def",
  "\t0 60 moveto",
  "\tmonth_name (  ) strcat yearstring strcat 700 center",
  "\tsubmonth 0 eq {",
  "\t\ttitlefont findfont footfontsize scalefont setfont",
  "\t\t/bottomrow { dayheight 6 mul 20 sub neg } def",
  "\t\t0 bottomrow moveto",
  "\t\tLfootstring show",
  "\t\tdaywidth 7 mul Rfootstring stringwidth pop sub",
  "\t\tbottomrow moveto",
  "\t\tRfootstring show",
  "\t\tdaywidth 7 mul Cfootstring stringwidth pop sub 2 div",
  "\t\tbottomrow moveto",
  "\t\tCfootstring show",
  "\t} if",
  "\t0 0 moveto",
  "\tdrawnums",
  "\t0 0 moveto",
  "\tdrawfill",
  "\t0 0 moveto",
  "\tdrawgrid",
  "} def",
  "/daytext {",
  "\tnotesfont findfont notesfontsize scalefont setfont",
  "\t/mytext\texch def /myday exch def",
  "\tstartday myday 1 sub add dup 7 mod daywidth mul 5 add % gives column",
  "\texch 7 idiv negdayheight mul % gives row",
  "\tdup /ypos exch def moveto",
  "\t/LM currentpoint pop def /RM LM 95 add def",
  "        mytext { dup (.p) eq { crlf pop} {prstr ( ) show} ifelse } forall",
  "} def",
  "/holidaytext {",
  "\tnotesfont findfont notesfontsize scalefont setfont",
  "\t/mytext\texch def /myday exch def",
  "\tstartday myday 1 sub add dup 7 mod daywidth mul",
  "\tmyday 10 lt {25} {40} ifelse add % gives column",
  "\texch 7 idiv negdayheight mul 27 add % gives row",
  "\tdup /ypos exch def moveto",
  "\t/LM currentpoint pop def /RM LM myday 10 lt {75} {60} ifelse add def",
  "        mytext { dup (.p) eq { crlf pop} {prstr ( ) show} ifelse } forall",
  "} def",
  "/crlf {",
  "    ypos 7 sub /ypos exch def LM ypos moveto",
  "} def",
  "/prstr {",
  "    dup stringwidth pop currentpoint pop",
  "    add RM gt {crlf (   ) show} if show",
  "} def",
  "/printmonth {",
   (char *)0,
 };
 
 char *header_2[] = {
  "\t/submonth 0 def",
  "\tcalendar",
  "\tmonth 1 sub 0 eq",
  "\t{",
  "\t\t/lmonth 12 def",
  "\t\t/lyear year 1 sub def",
  "\t}",
  "\t{",
  "\t\t/lmonth month 1 sub def",
  "\t\t/lyear year def",
  "\t} ifelse",
  "\tmonth 1 add 13 eq",
  "\t{",
  "\t\t/nmonth 1 def",
  "\t\t/nyear year 1 add def",
  "\t} ",
  "\t{",
  "\t\t/nmonth month 1 add def",
  "\t\t/nyear year def",
  "\t} ifelse",
  "\t/savemonth month def",
  "\t/saveyear year def",
  "\t/submonth 1 def",
  "\t/savedatefontsize datefontsize def",
  "\t/year lyear def",
  "\t/month lmonth def",
  "\t/datefontsize 48 def",
  "\tgsave",
  "\t500 -365 translate",
  "\tgsave",
  "\t.138 .138 scale",
  "\t10 -120 translate",
  "\tcalendar",
  "\tgrestore",
  "\t/submonth 1 def",
  "\t/year nyear def",
  "\t/month nmonth def",
  "\t100 0 translate",
  "\tgsave",
  "\t.138 .138 scale",
  "\t10 -120 translate",
  "\tcalendar",
  "\tgrestore",
  "\t/month savemonth def",
  "\t/year saveyear def",
  "\t/submonth 0 def",
  "\t/datefontsize savedatefontsize def",
  "\tgrestore",
  "} def",
  (char *)0,
};
